# Hooks

- [Actions](#actions)
- [Filters](#filters)

## Actions

### `pronamic_pay_webhook_log_payment`

*Webhook log payment.*

The `pronamic_pay_webhook_log_payment` action is triggered so the
`wp-pay/core` library can hook into this and register the webhook
call.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$payment` | `\Pronamic\WordPress\Pay\Payments\Payment` | Payment to log.

Source: [src/Gateway.php](../src/Gateway.php), [line 364](../src/Gateway.php#L364-L373)

## Filters

### `pronamic_pay_omnikassa_2_merchant_return_url`

*Filters the OmniKassa 2.0 merchant return URL.*

OmniKassa 2 requires for each order announcement a merchant return URL.
OmniKassa 2 does not allow all merchant return URL's. An order
announcement with a merchant return URL's with the TLD `.test` will
for example result in the following error:

> merchantReturnURL is not a valid web address

This can be very inconvenient for testing OmniKassa 2, therefor we
introduced this filter.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$merchant_return_url` | `string` | Merchant return URL.

Source: [src/Gateway.php](../src/Gateway.php), [line 96](../src/Gateway.php#L96-L113)

### `pronamic_pay_omnikassa_2_request_args`

*Filters the OmniKassa 2.0 remote request arguments.*

Developers who want to adjust the WordPress remote request arguments
towards the OmniKassa servers can use this filter. For example, it
can be used to increase the HTTP timeout to, for example, 3600. This
is sometimes useful for testing AfterPay payments for example.
Mainly because the OmniKassa servers sometimes respond slowly when
starting AfterPay payments.

**Arguments**

Argument | Type | Description
-------- | ---- | -----------
`$args` | `array` | WordPress remote request arguments.

Source: [src/Client.php](../src/Client.php), [line 170](../src/Client.php#L170-L183)


<p align="center"><a href="https://github.com/pronamic/wp-documentor"><img src="https://cdn.jsdelivr.net/gh/pronamic/wp-documentor@main/logos/pronamic-wp-documentor.svgo-min.svg" alt="Pronamic WordPress Documentor" width="32" height="32"></a><br><em>Generated by <a href="https://github.com/pronamic/wp-documentor">Pronamic WordPress Documentor</a> <code>1.1.0</code></em><p>

